PlugLocation class

A resolved GPS / map-picked location before it becomes a full PlugAddress.

Constructors

PlugLocation({required double lat, required double lng, String? address, String? shortAddress, String? city, String? state, String? country, String? pincode, String? placeId})
const
PlugLocation.fromJson(Map<String, dynamic> j)
factory

Properties

address String?
final
city String?
final
country String?
final
hashCode int
The hash code for this object.
no setterinherited
lat double
final
latlng → LatLng
no setter
lng double
final
pincode String?
final
placeId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shortAddress String?
final
state String?
final

Methods

copyWith({double? lat, double? lng, String? address, String? shortAddress, String? city, String? state, String? country, String? pincode, String? placeId}) PlugLocation
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited